This functions loads and checks the results file(s) from a new Envision instrument in the CSV or XLSX format. Supports multiple plates in a single file or multiple sheets in an Excel file by robustly checking the file structure.
Usage
load_results_EnVision_new(
results_file,
headers = gDRutils::get_env_identifiers()
)